@@ -34,7 +34,7 @@ our @EXPORT_OK =
   qw(BY_XPATH BY_ID BY_NAME BY_TAG BY_CLASS BY_SELECTOR BY_LINK BY_PARTIAL);
 our %EXPORT_TAGS = ( all => \@EXPORT_OK );
 
-our $VERSION = '0.35';
+our $VERSION = '0.36';
 
 sub _ANYPROCESS                    { return -1 }
 sub _COMMAND                       { return 0 }
@@ -63,12 +63,13 @@ sub new {
     my ( $class, %parameters ) = @_;
     my $self = bless {}, $class;
     $self->{last_message_id} = 0;
-    $self->{creation_pid} = $PROCESS_ID;
+    $self->{creation_pid}    = $PROCESS_ID;
     my @arguments = $self->_setup_arguments(%parameters);
     $self->{_pid} = $self->_launch(@arguments);
     my $socket = $self->_setup_local_connection_to_firefox(@arguments);
     my ( $session_id, $capabilities ) =
       $self->_initial_socket_setup( $socket, $parameters{capabilities} );
+
     if ( ($session_id) && ($capabilities) && ( ref $capabilities ) ) {
     }
     else {
@@ -111,13 +112,20 @@ sub _setup_arguments {
             push @arguments, '-headless';
             $self->{visible} = 0;
         }
-        elsif ( $self->_xvfb_exists() && ( $self->_launch_xvfb() ) ) {
-            $self->{_xvfb_support_for_headless} = 1;
-            $self->{visible}                    = 0;
+        elsif (( $OSNAME eq 'MSWin32' )
+            || ( $OSNAME ne 'darwin' )
+            || ( $OSNAME ne 'cygwin' ) )
+        {
         }
         else {
-            Carp::carp('Unable to launch firefox with -headless option');
-            $self->{visible} = 1;
+            if ( $self->_xvfb_exists() && ( $self->_launch_xvfb() ) ) {
+                $self->{_xvfb_support_for_headless} = 1;
+                $self->{visible}                    = 0;
+            }
+            else {
+                Carp::carp('Unable to launch firefox with -headless option');
+                $self->{visible} = 1;
+            }
         }
     }
     if ( $parameters{profile_name} ) {
@@ -341,9 +349,9 @@ sub _xvfb_exists {
               or Carp::croak("Failed to exec '$binary':$EXTENDED_OS_ERROR");
         } or do {
             if ( $self->_debug() ) {
-		    chomp $EVAL_ERROR;
-		    warn "$EVAL_ERROR\n";
-		}
+                chomp $EVAL_ERROR;
+                warn "$EVAL_ERROR\n";
+            }
         };
         exit 1;
     }
@@ -390,7 +398,8 @@ sub _launch_xauth {
         waitpid $pid, 0;
         if ( $CHILD_ERROR == 0 ) {
             close $source_handle
-              or Carp::croak("Failed to close temporary file:$EXTENDED_OS_ERROR");
+              or
+              Carp::croak("Failed to close temporary file:$EXTENDED_OS_ERROR");
             return 1;
         }
     }
@@ -410,9 +419,9 @@ sub _launch_xauth {
               or Carp::croak("Failed to exec '$binary':$EXTENDED_OS_ERROR");
         } or do {
             if ( $self->_debug() ) {
-		    chomp $EVAL_ERROR;
-		    warn "$EVAL_ERROR\n";
-		}
+                chomp $EVAL_ERROR;
+                warn "$EVAL_ERROR\n";
+            }
         };
         exit 1;
     }
@@ -493,9 +502,9 @@ sub _launch_xvfb {
               or Carp::croak("Failed to exec '$binary':$EXTENDED_OS_ERROR");
         } or do {
             if ( $self->_debug() ) {
-		    chomp $EVAL_ERROR;
-		    warn "$EVAL_ERROR\n";
-		}
+                chomp $EVAL_ERROR;
+                warn "$EVAL_ERROR\n";
+            }
         };
         exit 1;
     }
@@ -552,9 +561,9 @@ sub _launch_unix {
               or Carp::croak("Failed to exec '$binary':$EXTENDED_OS_ERROR");
         } or do {
             if ( $self->_debug() ) {
-            chomp $EVAL_ERROR;
-            warn "$EVAL_ERROR\n";
-		}
+                chomp $EVAL_ERROR;
+                warn "$EVAL_ERROR\n";
+            }
         };
         exit 1;
     }
@@ -2256,8 +2265,8 @@ sub _signal_number {
 
 sub DESTROY {
     my ($self) = @_;
-    if ($self->{creation_pid} == $PROCESS_ID) {
-	    $self->quit();
+    if ( $self->{creation_pid} == $PROCESS_ID ) {
+        $self->quit();
     }
     return;
 }
@@ -2271,7 +2280,7 @@ Firefox::Marionette - Automate the Firefox browser with the Marionette protocol
 
 =head1 VERSION
 
-Version 0.35
+Version 0.36
 
 =head1 SYNOPSIS
 
